<a id="the-lightweight-library-for-async-messaging-nobody-expects"></a>

# The lightweight library for async messaging nobody expects.

*Installation*

pip install eric-sse

*Related packages*

* https://pypi.org/project/eric-redis-queues/ Redis integration
* https://pypi.org/project/eric-api/ FastApi microservice

*Features*

* Send to one listener and broadcast
* SSE format was adopted by design, making the library suitable for such kind of model
* Callbacks and threading support
* Sockets server prefab for offline inter process communication

*Possible applications*

* Message delivery mechanisms based on SSE
* Message queue processing (logging, etc)
* See [https://github.com/laxertu/eric-api](https://github.com/laxertu/eric-api)

*Documentation*

* Home [https://laxertu.github.io/eric](https://laxertu.github.io/eric)


*Trivia*

* Library name pretends to be a tribute to the following movie [https://en.wikipedia.org/wiki/Looking_for_Eric](https://en.wikipedia.org/wiki/Looking_for_Eric)
